@@ -2,7 +2,7 @@
 Date         : 2022-12-18 12:32:53
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-12-18 12:47:54
+LastEditTime : 2023-01-20 13:38:58
 LastEditors  : BDFD
 Description  : 
 FilePath     : \WES_Calculation\__init__.py
@@ -15,4 +15,10 @@ from WES_Calculation.gumbel import gumbel
 from WES_Calculation.greenampt import greenampt
 from WES_Calculation.wavespectra import wave
 from WES_Calculation.windspeed import windspeed
+from WES_Calculation.preprocess import pre_gumbel as gu
+from WES_Calculation.preprocess import pre_greenampt as ga
+from WES_Calculation.preprocess import pre_wavespectra as wa
+from WES_Calculation.preprocess  import pre_windspeed as ws
+
+
 
