@@ -2,7 +2,7 @@
 Date         : 2022-12-18 12:33:46
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-12-21 11:15:15
+LastEditTime : 2023-01-24 12:13:26
 LastEditors  : BDFD
 Description  : 
 FilePath     : \WES_Calculation\windspeed.py
@@ -18,6 +18,7 @@ import base64
 from datetime import datetime as dt
 import time
 
+from .ref_func import phi1f, psi1f, psi2f, A, B, att
 
 def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
     # if o2==3:
@@ -48,62 +49,6 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
     #legend_font = {'family' : 'Times New Roman'}
     plt.rc('legend', fontsize='small')# medium
 
-    # Functions 
-    def phi1f(z,x): # a function of solving phi (phi^4-gammap*phi^3*z/L'=1), in which x=L'.
-        le=phi1l # the upper end of phi range
-        ue=phi1u # the lower end of phi range
-        mp=0.5*(le+ue) # the mid point between both ends
-        while abs(mp**4-gammap*mp**3*z/x-1)>tol:   
-            if mp**4-gammap*mp**3*z/x-1>0:
-                ue=mp 
-            else:
-                le=mp
-            mp=0.5*(le+ue)
-        return mp
-
-    def psi1f(x): # the psi function in terms of phi (for KEYPS Model) 
-        y=1-x-3*math.log(x)+2*math.log(0.5+0.5*x)+2*math.atan(x)-0.5*math.pi+math.log(0.5+0.5*x**2)
-        return y
-
-    def psi2f(x): # the psi function in terms of phi (for B-D Model) 
-        y=math.log((1+x)**2*(1+x**2)/8)-2*math.atan(x)+0.5*math.pi 
-        return y
-
-    def A(x): # A function in the ABL resistance law
-        if x<=0:
-            Af = 1.1+3.7241*math.log(1-0.02*x)
-        else:
-            Af = 1.1-6.364*math.log(1+0.02*x)			 
-        return Af
-
-    def B(x): # B function in the ABL resistance law
-        if x<=0:
-            Bf = 4.3-(4.3-0.23)*(1-math.exp(0.03*x))         
-        else:
-            Bf = 4.3+0.7*x**0.5			 
-        return Bf
-
-    def att(u1,t1,t2): # a function transforming widnspeeds between different averaging times (AT) by the CEM method
-    # u1: windspeed (m/s) at AT t1 (min), u2: windspeed (m/s) at AT t2 (min)
-        if 1/60<t1<=60:
-            if 1/60<t2<=60:
-                if t2==60:                
-                    u2=np.array(u1)/(1.277+0.296*math.tanh(0.9*math.log10(45/t1/60)))*(t1!=60)+np.array(u1)*(t1==60)
-                else:
-                    u2=(1.277+0.296*math.tanh(0.9*math.log10(45/t2/60)))*np.array(u1)/(1.277+0.296*math.tanh(0.9*math.log10(45/t1/60)))*(t1!=60)+(1.277+0.296*math.tanh(0.9*math.log10(45/t2/60)))*np.array(u1)*(t1==60)
-            if 60<t2<600:
-                u2=(1.5334-0.15*math.log10(t2*60))*np.array(u1)/(1.277+0.296*math.tanh(0.9*math.log10(45/t1/60)))*(t1!=60)+(1.5334-0.15*math.log10(t2*60))*np.array(u1)*(t1==60)       
-        if 60<t1<600:
-            if 1/60<t2<=60:
-                if t2==60:
-                    u2=np.array(u1)/(1.5334-0.15*math.log10(t1*60))
-                else:
-                    u2=(1.277+0.296*math.tanh(0.9*math.log10(45/t2/60)))*np.array(u1)/(1.5334-0.15*math.log10(t1*60))
-            if 60<t2<600:
-                Up1=(1.5334-0.15*math.log10(t2*60))*np.array(u1)/(1.5334-0.15*math.log10(t1*60))
-        return u2
-
-
     # 1. Basic Windspeed Calculations
     if TaaC==None:
         TaaC=Ta
@@ -751,8 +696,8 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
     plt.rcParams['axes.unicode_minus'] = False
     todayis = dt.utcnow()
     d1 = todayis.strftime("%Y%m%d%H%M%S")
-    # plt.savefig(f'pichistory/{d1}-wavespectra.png',dpi = 300)
-    # plt.savefig(f'var/www/flaskapp/pichistory/{d1}-wavespectra.png',dpi = 300)
+    # plt.savefig(f'pichistory/{d1}-windspeed.png',dpi = 300)
+    # plt.savefig(f'var/www/flaskapp/pichistory/{d1}-windspeed.png',dpi = 300)
     img = io.BytesIO()
     plt.savefig(img, format='png')
     img.seek(0)
